{#-
  This file was automatically generated - do not edit
-#}
{% extends "base.html" %}
{% block extrahead %}
  <link rel="stylesheet" href="{{ 'assets/stylesheets/custom.f120bdc6.min.css' | url }}">
{% endblock %}
{% block announce %}
  For updates follow <strong>@squidfunk</strong> on
  <a rel="me" href="https://fosstodon.org/@squidfunk">
    <span class="twemoji mastodon">
      {% include ".icons/fontawesome/brands/mastodon.svg" %}
    </span>
    <strong>Fosstodon</strong>
  </a>
  and
  <a href="https://x.com/squidfunk">
    <span class="twemoji twitter">
      {% include ".icons/fontawesome/brands/twitter.svg" %}
    </span>
    <strong>Twitter</strong>
  </a>
{% endblock %}
{% block scripts %}
  {{ super() }}
  <script src="{{ 'assets/javascripts/custom.f46acd93.min.js' | url }}"></script>
{% endblock %}
