{#-
  This file was automatically generated - do not edit
-#}
{% macro t(key) %}{{ {
  "language": "nb",
  "action.edit": "Rediger denne siden",
  "action.skip": "Gå til innhold",
  "action.view": "Vis kildekoden til denne siden",
  "announce.dismiss": "Ikke vis dette igjen",
  "blog.archive": "Arkiv",
  "blog.categories": "Kategorier",
  "blog.categories.in": "i",
  "blog.continue": "Fortsett å lese",
  "blog.draft": "Kladd",
  "blog.index": "Tilbake til oversikt",
  "blog.meta": "Metadata",
  "blog.references": "Relaterte lenker",
  "clipboard.copy": "Kopier til utklippstavlen",
  "clipboard.copied": "Kopiert til utklippstavlen",
  "consent.accept": "Akseptert",
  "consent.manage": "Innstillinger",
  "consent.reject": "Reject",
  "footer": "Footer",
  "footer.next": "Neste",
  "footer.previous": "Forrige",
  "header": "Header",
  "meta.comments": "Kommentarer",
  "meta.source": "Kilde",
  "nav": "Navigasjon",
  "readtime.one": "lesetid: 1 min",
  "readtime.other": "lesetid: # min",
  "rss.created": "RSS feed",
  "rss.updated": "Oppdatert RSS feed",
  "search": "Søk",
  "search.config.lang": "no",
  "search.placeholder": "Søk",
  "search.share": "Del",
  "search.reset": "Nullstill",
  "search.result.initializer": "Starter søk",
  "search.result.placeholder": "Skriv søkeord",
  "search.result.none": "Ingen treff",
  "search.result.one": "1 treff",
  "search.result.other": "# treff",
  "search.result.more.one": "1 til på denne siden",
  "search.result.more.other": "# flere på denne siden",
  "search.result.term.missing": "Mangler",
  "select.language": "Velg språk",
  "select.version": "Velg versjon",
  "source": "Gå til kilde",
  "source.file.contributors": "Bidragsytere",
  "source.file.date.created": "Opprettet",
  "source.file.date.updated": "Sist oppdatert",
  "tabs": "Faner",
  "toc": "Innholdsliste",
  "top": "Tilbake til toppen"
}[key] }}{% endmacro %}
